/*
 * Copyright (c) Huawei Technologies Co., Ltd. 2020-2024. All rights reserved.
 */

#ifndef PERCEPTION_IMPL_TYPE_LIDAR2LIDARPERCEPTION_H
#define PERCEPTION_IMPL_TYPE_LIDAR2LIDARPERCEPTION_H

#include "perception/impl_type_sensorheader.h"
#include "perception/impl_type_vectorpointxyzit.h"

namespace perception {
struct LiDAR2LiDARPerception {
    ::perception::SensorHeader header;
    ::perception::VectorPointXYZIT points;

    static bool IsPlane()
    {
        return false;
    }


    using IsEnumerableTag = void;
    template<typename F>
    void enumerate(F& fun)
    {
        fun(header);
        fun(points);
    }

    template<typename F>
    void enumerate(F& fun) const
    {
        fun(header);
        fun(points);
    }

    template<typename F>
    void enumerate_internal(F& fun)
    {
        fun("header", header);
        fun("points", points);
    }

    template<typename F>
    void enumerate_internal(F& fun) const
    {
        fun("header", header);
        fun("points", points);
    }

    friend bool operator==(const ::perception::LiDAR2LiDARPerception& lhs, const ::perception::LiDAR2LiDARPerception& rhs) noexcept
    {
        return (lhs.header == rhs.header) && (lhs.points == rhs.points);
    }
};
} // namespace perception


#endif // PERCEPTION_IMPL_TYPE_LIDAR2LIDARPERCEPTION_H
